/*****************************************************************************
*    Open LiteSpeed is an open source HTTP server.                           *
*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
*                                                                            *
*    This program is free software: you can redistribute it and/or modify    *
*    it under the terms of the GNU General Public License as published by    *
*    the Free Software Foundation, either version 3 of the License, or       *
*    (at your option) any later version.                                     *
*                                                                            *
*    This program is distributed in the hope that it will be useful,         *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of          *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
*    GNU General Public License for more details.                            *
*                                                                            *
*    You should have received a copy of the GNU General Public License       *
*    along with this program. If not, see http://www.gnu.org/licenses/.      *
*****************************************************************************/
#include <thread/thread.h>


void Thread::cleanup(void * arg)
{
    ((Thread *)arg)->thr_cleanup();
}


void Thread::sigBlock()
{
    if (m_sigBlock) {
        pthread_sigmask(SIG_BLOCK, m_sigBlock, NULL);
    }
}


void * Thread::start_routine(void * arg)
{
    Thread *pThread = (Thread *)arg;

    pThread->sigBlock();

    void * ret = NULL;
    pthread_cleanup_push(cleanup, pThread);
    ret = pThread->thr_main(pThread->m_arg);
    pthread_cleanup_pop(1);
    return ret;
}


